unit cpqdExecuteScript;

interface

uses
  { VCL/RTL }
  Windows, SysUtils, Classes, Forms,
  {Library}
  UpdateServer_TLB;

type

  TqdScriptType = (stUPDATE, stMAINTANED);
  TqdGetPassword = function: boolean of object;
  TqdShowErrorMsg = procedure(CodError: Integer) of object;

  TqdExecuteScript = class(TComponent)
  protected
    UpdateServer: IqdUpdateServer;
    FScriptFileName: String;
    FScriptType: TqdScriptType;
    FPasswordsLst: TStringList;
    FOnGetPassword: TqdGetPassword;
    FOnShowErrorMsg: TqdShowErrorMsg;
    function  DoGetPassword: Boolean;
    procedure DoShowErrorMsg(CodeError: Integer);
    function  GetScriptFileName: String;
    procedure SetScriptFileName(Value: String);
  public
    procedure AddPasswords(pws: array of string);
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    function Execute(Path, NewPath: String): Integer;
    property ScriptType: TqdScriptType read FScriptType write FScriptType;
  published
    property ScriptFileName: String read GetScriptFileName write SetScriptFileName;
    property OnGetPassword: TqdGetPassword read FOnGetPassword write FOnGetPassword;
    property OnShowErrorMsg: TqdShowErrorMsg read FOnShowErrorMsg write FOnShowErrorMsg;
  end;

implementation

Uses
  { VCL/RTL }
  DbTables,
  { Library }
  ctqdConsts, clqdException;

procedure TqdExecuteScript.AddPasswords(pws: array of string);
var
  a: Integer;
begin
  FPasswordsLst.Clear;
  for a := 0 to High(pws) do
    FPasswordsLst.Add(pws[a]);
end;

constructor TqdExecuteScript.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  FPasswordsLst := TStringList.Create;
end;

destructor TqdExecuteScript.Destroy;
begin
  FPasswordsLst.Free;
  inherited Destroy;
end;

function TqdExecuteScript.DoGetPassword: Boolean;
begin
  if Assigned(OnGetPassword) then
    Result := OnGetPassword
  else
    Result := False;
end;

procedure TqdExecuteScript.DoShowErrorMsg(CodeError: Integer);
begin
  if Assigned(OnShowErrorMsg) then
    OnShowErrorMsg(CodeError);
end;

function TqdExecuteScript.Execute(Path, NewPath: String): Integer;
var
  a: Integer;
  ScriptFN: String;
begin
  if ScriptType = stUPDATE then
    ScriptFN := ScriptFileName + ctqdSCRIPTUPDATEEXT
  else
    ScriptFN := ScriptFileName + ctqdSCRIPTMAINTAINEXT;
  if FileExists(ScriptFN) then begin
    if Not Assigned(UpdateServer) then
      UpdateServer := CoqdUpdateServer.Create;
    UpdateServer.AliasPath := Path;
    UpdateServer.NewAliasPath := NewPath;
    UpdateServer.UpdateFileName := ScriptFN;
    for a := 0 to FPasswordsLst.Count - 1 do
     UpdateServer.addPassword(FPasswordsLst.Strings[a]);
    Result := UpdateServer.Execute;
  end else
    Result := ERRRS_SCRIPTFILENOTFOUND;
 if Result <> NOERROR then
   DoShowErrorMsg(Result)
end;

function TqdExecuteScript.GetScriptFileName: String;
begin
  Result := FScriptFileName
end;

procedure TqdExecuteScript.SetScriptFileName(Value: String);
begin
  if FScriptFileName <> Value then
    FScriptFileName := Value
end;

end.
